@@ -184,7 +184,7 @@ class RebaseCommand(Command):
             if not stash[1].startswith('No local changes'):
                 pop = M.git().stash(command='pop')
                 if pop[0] != 0:
-                    logging.error('An error ocured while unstashing your changes')
+                    logging.error('An error occurred while unstashing your changes')
                     logging.debug(pop[2])
                 else:
                     logging.info('Popped the stash')
