@@ -33,6 +33,13 @@ from ..tools import parseBranch, getText
 class TrackerCommand(Command):
 
     _arguments = [
+        (
+            ['--open'],
+            {
+                'action': 'store_true',
+                'help': 'Open issue in browser'
+            }
+        ),
         (
             ['-t', '--testing'],
             {
@@ -95,9 +102,14 @@ class TrackerCommand(Command):
         if not issue or not re.match('(MDL|mdl)?(-|_)?[1-9]+', issue):
             raise Exception('Invalid or unknown issue number')
 
-        self.Jira = Jira()
         self.mdl = 'MDL-' + re.sub(r'(MDL|mdl)(-|_)?', '', issue)
 
+        if args.open:
+            Jira.openInBrowser(self.mdl)
+            return
+
+        self.Jira = Jira()
+
         if args.addlabels:
             if 'triaged' in args.addlabels:
                 self.argumentError('The label \'triaged\' cannot be added using MDK')
