@@ -68,7 +68,7 @@ mdk_set_config('cachetemplates', 0);
 
 // Adds moodle_database declaration to help VSCode detect moodle_database.
 $varmoodledb = '/** @var moodle_database */
-$DB = $DB;
+$DB = isset($DB) ? $DB : null;
 ';
 $conffile = dirname(__FILE__) . '/config.php';
 if ($content = file_get_contents($conffile)) {
