@@ -17,12 +17,24 @@ cron_setup_user();
 // Enable the Web Services.
 set_config('enablewebservices', 1);
 
+// Enable mobile web services.
+set_config('enablemobilewebservice', 1);
+
 // Enable Web Services documentation.
 set_config('enablewsdocumentation', 1);
 
 // Enable each protocol.
 set_config('webserviceprotocols', 'amf,rest,soap,xmlrpc');
 
+// Enable mobile service.
+$webservicemanager = new webservice();
+$mobileservice = $webservicemanager->get_external_service_by_shortname(MOODLE_OFFICIAL_MOBILE_SERVICE);
+$mobileservice->enabled = 1;
+$webservicemanager->update_external_service($mobileservice);
+
+// Enable capability to use REST protocol.
+assign_capability('webservice/rest:use', CAP_ALLOW, $CFG->defaultuserroleid, SYSCONTEXTID, true);
+
 // Create the Web Service user.
 $user = $DB->get_record('user', array('username' => 'testtete'));
 if (!$user) {
@@ -43,7 +55,11 @@ if (!$roleid = $DB->get_field('role', 'id', array('shortname' => 'testtete'))) {
 $context = context_system::instance();
 set_role_contextlevels($roleid, array($context->contextlevel));
 role_assign($roleid, $user->id, $context->id);
-$capabilities = fetch_context_capabilities($context);
+if (method_exists($context, 'get_capabilities')) {
+    $capabilities = $context->get_capabilities();
+} else{
+    $capabilities = fetch_context_capabilities($context);
+}
 foreach ($capabilities as $capability) {
     assign_capability($capability->name, CAP_ALLOW, $roleid, $context->id, true);
 }
@@ -58,6 +74,7 @@ if (!$service = $DB->get_record('external_services', array('shortname' => 'mdk_a
     $service->enabled = 1;
     $service->restrictedusers = 1;
     $service->downloadfiles = 1;
+    $service->uploadfiles = 1;
     $service->id = $webservicemanager->add_external_service($service);
 }
 $functions = $webservicemanager->get_not_associated_external_functions($service->id);
